summaryrefslogtreecommitdiff
path: root/paste/httpexceptions.py
diff options
context:
space:
mode:
authorcce <devnull@localhost>2005-12-30 01:07:34 +0000
committercce <devnull@localhost>2005-12-30 01:07:34 +0000
commit22bbbfc3a4042fe981d81f9fa90a100e4160af3c (patch)
tree462106bcbac8ecfa5a06f6f776111543a49c1ef1 /paste/httpexceptions.py
parent190a2253158d24da3261ce8d16f5323d2727794e (diff)
downloadpaste-22bbbfc3a4042fe981d81f9fa90a100e4160af3c.tar.gz
- fixing my awful spelling
Diffstat (limited to 'paste/httpexceptions.py')
-rw-r--r--paste/httpexceptions.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/paste/httpexceptions.py b/paste/httpexceptions.py
index 0ccd83d..df08776 100644
--- a/paste/httpexceptions.py
+++ b/paste/httpexceptions.py
@@ -111,16 +111,16 @@ class HTTPException(Exception):
``explanation``
a plain-text explanation of the error message that is
not subject to environment or header substitutions;
it is accessable in the template via %(explanation)s
``detail``
a plain-text message customization that is not subject
- to environment or header substutions; accessable in
+ to environment or header substations; accessible in
the template via %(detail)s
``template``
a content fragment (in HTML) used for environment and
- header substution; the default template includes both
+ header substitution; the default template includes both
the explanation and further detail provided in the
message
@@ -140,7 +140,7 @@ class HTTPException(Exception):
after it has been created. This particular breakdown of a message
into explanation, detail and template allows both the creation of
plain-text and html messages for various clients as well as
error-free substution of environment variables and headers.
"""
code = None
@@ -235,7 +235,7 @@ class HTTPException(Exception):
class HTTPError(HTTPException):
"""
- This is an exception which indicates that an error has occured,
+ This is an exception which indicates that an error has occurred,
and that any work in progress should not be committed. These are
typically results in the 400's and 500's.
"""
@@ -111,16 +111,16 @@ class HTTPException(Exception):
a plain-text explanation of the error message that is
not subject to environment or header substitutions;
- it is accessable in the template via %(explanation)s
+ it is accessible in the template via %(explanation)s
``detail``
a plain-text message customization that is not subject
@@ -140,7 +140,7 @@ class HTTPException(Exception):
into explanation, detail and template allows both the creation of
plain-text and html messages for various clients as well as
- error-free substution of environment variables and headers.
+ error-free substitution of environment variables and headers.
"""
code = None